@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "17.0.8.1+1" },
-            { "jdk", "17.0.8.1" },
-            { "release", "17.0.8.1" },
+            { "full", "17.0.9+9" },
+            { "jdk", "17.0.9" },
+            { "release", "17.0.9" },
         };
     }
 }
